@@ -1,5 +1,6 @@
 #modified March 4, 2009 for matrix output
 #and yet again August 1 to make it actually work!
+#modified May 26, 2014 to add the ability to specify group by name or location
 "describe.by" <-
 function (x,group=NULL,mat=FALSE,type=3,...) {               #data are x, grouping variable is group
 .Deprecated("describeBy", msg = "describe.by is deprecated.  Please use the describeBy function")
@@ -11,6 +12,7 @@ return(answer)}
 function (x,group=NULL,mat=FALSE,type=3,digits=15,...) {               #data are x, grouping variable is group
 if(is.null(group)) {answer <- describe(x,type=type)
    warning("no grouping variable requested")} else {
+   if(!is.data.frame(group) && !is.list(group) && (length(group) < NROW(x))) group <- x[,group]
 		answer <- by(x,group,describe,type=type,...)
       	 #class(answer) <- c("psych","describe")  #probably better not to make of class psych (at least not yet)
        	}
