@@ -1,10 +1,10 @@
 "omegah" <-
-function(m,nfactors=3,fm="minres",key=NULL,flip=TRUE, digits=2,title="Omega",sl=TRUE,labels=NULL, plot=TRUE,n.obs=NA,rotate="oblimin",Phi = NULL,option="equal",...) {
+function(m,nfactors=3,fm="minres",key=NULL,flip=TRUE, digits=2,title="Omega",sl=TRUE,labels=NULL, plot=TRUE,n.obs=NA,rotate="oblimin",Phi = NULL,option="equal",covar=FALSE,...) {
       #m is a correlation matrix, or if not, the correlation matrix is found
       #nfactors is the number of factors to extract
       #key allows items to be reversed scored  if desired
       #if Phi is not null, this implies that we have been given a factor matrix  -- added May 30, 2010
-     if(!require(GPArotation) && (rotate !="cluster")) {stop("I am sorry, you need to have the  GPArotation package installed")}
+     if(!requireNamespace('GPArotation') && (rotate !="cluster")) {stop("I am sorry, you need to have the  GPArotation package installed")}
       cl <- match.call() 
       nvar <- dim(m)[2]
       raw.data <- NULL
@@ -13,9 +13,9 @@ function(m,nfactors=3,fm="minres",key=NULL,flip=TRUE, digits=2,title="Omega",sl=
                             n.obs <- dim(m)[1]
                             m <- as.matrix(m)
                             raw.data <- m #added 9/1/14
-                            m <- cor(m,use="pairwise")
+                            if(covar) {m <- cov(m,use="pairwise") } else {m <- cor(m,use="pairwise")}
                             } else {
-                            m <- cov2cor(as.matrix(m))    #make sure it is a correlation matrix not a covariance or data matrix (if we change this, we will need to change the calculation for omega later)
+                            if(!covar) m <- cov2cor(as.matrix(m))    #make sure it is a correlation matrix not a covariance or data matrix (if we change this, we will need to change the calculation for omega later)
                            }
                             
       if(is.null(colnames(m))) {  rownames(m) <- colnames(m) <- paste("V",1:nvar,sep="") }
@@ -33,7 +33,7 @@ function(m,nfactors=3,fm="minres",key=NULL,flip=TRUE, digits=2,title="Omega",sl=
        fm <- "minres"} 
        } else { m.names <- rownames(m) }   #add the names if we have a factor input 
        
-      gf <-schmid(m,nfactors,fm,digits,rotate=rotate,n.obs=n.obs,Phi=Phi,option=option, ...)
+      gf <-schmid(m,nfactors,fm,digits,rotate=rotate,n.obs=n.obs,Phi=Phi,option=option,covar=covar, ...)
       if(!is.null(Phi)) { model <- m
                          nfactors <- dim(model)[2]
                           m <- factor.model(model,Phi=Phi,U2=FALSE)
@@ -63,13 +63,14 @@ function(m,nfactors=3,fm="minres",key=NULL,flip=TRUE, digits=2,title="Omega",sl=
        
      
       gsq <- (sum(gload))^2
-      uniq <- sum(gf$sl[,(nfactors+3)])
+      uniq <- sum(gf$sl[,"u2"])
+      
       if((nfactors == 1) && (fm=="pc")) {gsq <- Vt - uniq
                                         warning("omega_h is not meaningful for a principal components analysis with one component")}   #weird condition when using fm=pc and 1 factor
       om.tot <- (Vt-uniq)/Vt
       om.limit <- gsq/(Vt-uniq)  
       alpha <- ((Vt-Vitem)/Vt)*(nvar/(nvar-1))
-      sum.smc <- sum(smc(m))
+      sum.smc <- sum(smc(m,covar=covar))
       lambda.6 <- (Vt +sum.smc-sum(diag(m)))/Vt
       if (!is.null(digits)) {omega <-list(omega_h= gsq/Vt,alpha=alpha,lambda.6 = lambda.6,omega.tot =om.tot,schmid=gf ,key = key,title=title)
             dg <-max(digits-1,1)} else {
@@ -82,7 +83,7 @@ function(m,nfactors=3,fm="minres",key=NULL,flip=TRUE, digits=2,title="Omega",sl=
      if (nfactors<2) plot <- FALSE
     # if(require(Rgraphviz) && plot) {omega.model <-omega.graph(omega,title=title,sl=sl,labels=labels,digits=dg) } else {omega.model <- omega.sem(omega,sl=sl)}
    
-   omega.model <- omega.sem(omega,sl=sl)
+     omega.model <- omega.sem(omega,sl=sl)
      
      #find the subset omegas
      omg <- omgo <- omt<-  rep(NA,nfactors+1)
@@ -117,10 +118,10 @@ function(m,nfactors=3,fm="minres",key=NULL,flip=TRUE, digits=2,title="Omega",sl=
 
 
 "omega" <- 
-function(m,nfactors=3,fm="minres",n.iter=1,p=.05,poly=FALSE,key=NULL,flip=TRUE, digits=2,title="Omega",sl=TRUE,labels=NULL, plot=TRUE,n.obs=NA,rotate="oblimin",Phi = NULL,option="equal",...) {
+function(m,nfactors=3,fm="minres",n.iter=1,p=.05,poly=FALSE,key=NULL,flip=TRUE, digits=2,title="Omega",sl=TRUE,labels=NULL, plot=TRUE,n.obs=NA,rotate="oblimin",Phi = NULL,option="equal",covar=FALSE,...) {
  cl <- match.call()
   if(is.data.frame(m) || is.matrix(m)) {if(dim(m)[1] == dim(m)[2] ) {if(is.na(n.obs) && (n.iter>1)) stop("You must specify the number of subjects if giving a correlation matrix")
-                                 if(!require(MASS)) stop("You must have MASS installed to simulate data from a correlation matrix")
+                                # if(!require(MASS)) stop("You must have MASS installed to simulate data from a correlation matrix")
                                  }
                   }
  if(!is.data.frame(m) && !is.matrix(m)) {  n.obs=m$n.obs
@@ -135,7 +136,7 @@ function(m,nfactors=3,fm="minres",n.iter=1,p=.05,poly=FALSE,key=NULL,flip=TRUE,
           if(poly) { pol <- polychoric(m)
                      m <- pol$rho
                      n.obs <- pol$n.obs}  }       
-            om <- omegah(m=m,nfactors=nfactors,fm=fm,key=key,flip=flip, digits=digits,title=title,sl=sl,labels=labels, plot=plot,n.obs=n.obs,rotate=rotate,Phi = Phi,option=option,...) #call omega with the appropriate parameters
+            om <- omegah(m=m,nfactors=nfactors,fm=fm,key=key,flip=flip, digits=digits,title=title,sl=sl,labels=labels, plot=plot,n.obs=n.obs,rotate=rotate,Phi = Phi,option=option,covar=covar,...) #call omega with the appropriate parameters
     
 
        
@@ -144,10 +145,12 @@ function(m,nfactors=3,fm="minres",n.iter=1,p=.05,poly=FALSE,key=NULL,flip=TRUE,
  if(n.iter > 1) {for (trials in 1:n.iter) {
  if(dim(m)[1] == dim(m)[2]) {#create data sampled from multivariate normal with correlation
                                       nvar <- dim(m)[1]
-                                      mu <- rep(0, nvar)
-                                      m <- mvrnorm(n = n.obs, mu, Sigma = m, tol = 1e-06, 
-                                   empirical = FALSE)
-
+                                      #mu <- rep(0, nvar)
+                                     # m <- mvrnorm(n = n.obs, mu, Sigma = m, tol = 1e-06, empirical = FALSE)
+ #the next 3 lines replaces mvrnorm (taken from mvrnorm, but without the checks)
+                                      eX <- eigen(m)
+                                      m <- matrix(rnorm(nvar * n.obs),n.obs)
+                                      m <-  t(eX$vectors %*% diag(sqrt(pmax(eX$values, 0)), nvar) %*%  t(m))
                             } else {m <- m[sample(n.obs,n.obs,replace=TRUE),]}
     if(poly) {pol <- polychoric(m)
             oms <- omegah(m=pol$rho,nfactors=nfactors,fm=fm,key=key,flip=flip, digits=digits,title=title,sl=sl,labels=labels, plot=plot,n.obs=pol$n.obs,rotate=rotate,Phi = Phi,option=option,...) #call omega with the appropriate parameters
