@@ -4,7 +4,7 @@ function(m,nfactors=3,fm="minres",key=NULL,flip=TRUE, digits=2,title="Omega",sl=
       #nfactors is the number of factors to extract
       #key allows items to be reversed scored  if desired
       #if Phi is not null, this implies that we have been given a factor matrix  -- added May 30, 2010
-if(!require(sem)) stop("You must have the sem package installed to use omegaSem")
+if(!requireNamespace('sem')) stop("You must have the sem package installed to use omegaSem")
 if (!sl) {warning("OmegaSem only works for Bifactor models, sl set to TRUE ")
     sl <- TRUE}
 
@@ -31,15 +31,16 @@ if(is.na(n.obs)) {message("Number of observations not specified. Arbitrarily set
                             
       if(is.null(colnames(m))) {  rownames(m) <- colnames(m) <- paste("V",1:nvar,sep="") }
        m.names <- colnames(m)
-if(!require(sem)) {stop("You must have the sem package installed to use omegaSem")
- } else {sem.om <- sem(sem.model,m, n.obs) }
+if(!requireNamespace('sem')) {stop("You must have the sem package installed to use omegaSem")
+  
+ } else {sem.om <- sem::sem(sem.model,m, n.obs) }
 omega.efa <- omegaFromSem(m,sem.om,flip=flip)
 results <- list(omegaSem=om,omega.efa=omega.efa,sem=sem.om,Call=cl)
 class(results) <- c("psych", "omegaSem")
 return(results)
 }
 #modified Sept 1 to pass the number of observations to SEM
-
+#modified Jan 2, 2015 to call sem::sem  which seems to be the preferred manner
 
 "omegaFromSem" <- 
 function(m,s,flip=TRUE) {
